@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: app.c 12238 2011-03-25 22:04:24Z yeti-dn $
+ *  @(#) $Id: app.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -776,7 +776,8 @@ _gwy_app_3d_window_setup(Gwy3DWindow *window3d)
     view3d = GWY_3D_VIEW(gwy_3d_window_get_3d_view(window3d));
     tooltips = gwy_3d_window_class_get_tooltips();
 
-    button = gwy_stock_like_button_new(_("Save"), GTK_STOCK_SAVE);
+    button = gwy_stock_like_button_new(gwy_sgettext("verb|Save"),
+                                       GTK_STOCK_SAVE);
     gtk_tooltips_set_tip(tooltips, button,
                          _("Save 3D view to an image"), NULL);
     gwy_3d_window_add_action_widget(GWY_3D_WINDOW(window3d), button);
