@@ -31,6 +31,8 @@ static const gchar translators[] =
     "Petr Klapetek\n"
     "Livia Della Seta\n"
     "Philipp Leufke\n"
+    "Johannes Römer\n"
     "François Riguet\n"
     "Даниил Браташов\n"
+    "Andrés Muñiz Piniella\n"
 ;
