@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: file.c 10255 2009-10-16 11:40:32Z yeti-dn $
+ *  @(#) $Id: file.c 12508 2011-06-05 11:36:17Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -175,7 +175,8 @@ warn_broken_load_func(const gchar *name,
                       GwyContainer *data)
 {
     static const gchar *broken_file_funcs[] = {
-        "nanonics",
+        "ambfile",
+        /*"at present no modules are broken and this is not a file type name",*/
     };
 
     FindFileFuncModuleData ffdata;
@@ -255,7 +256,8 @@ gwy_app_file_load_real(const gchar *filename_utf8,
         data = gwy_file_func_run_load(name, filename_sys,
                                       GWY_RUN_INTERACTIVE, &err);
     else
-        data = gwy_file_load(filename_sys, GWY_RUN_INTERACTIVE, &err);
+        data = gwy_file_load_with_func(filename_sys, GWY_RUN_INTERACTIVE,
+                                       &name, &err);
 
     if (data) {
         gwy_data_validate(data,
@@ -268,13 +270,26 @@ gwy_app_file_load_real(const gchar *filename_utf8,
         if (err && !g_error_matches(err,
                                     GWY_MODULE_FILE_ERROR,
                                     GWY_MODULE_FILE_ERROR_CANCELLED)) {
+            gchar *filename_disp = g_filename_display_basename(filename_utf8);
+            GString *message = g_string_new(NULL);
+
             dialog = gtk_message_dialog_new(NULL, 0,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             _("Opening of `%s' failed"),
-                                            filename_utf8);
+                                            filename_disp);
+            g_free(filename_disp);
+            g_string_append(message, err->message);
+            g_string_append(message, "\n\n");
+            g_string_append_printf(message,
+                                   _("Full file path: %s."), filename_utf8);
+            if (name) {
+                g_string_append(message, "\n\n");
+                g_string_append_printf(message, _("Loaded using: %s."), name);
+            }
             gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-                                                     "%s", err->message);
+                                                     "%s", message->str);
+            g_string_free(message, TRUE);
             g_signal_connect(dialog, "response",
                              G_CALLBACK(gtk_widget_destroy), NULL);
             gtk_widget_show_all(dialog);
@@ -339,9 +354,7 @@ gwy_app_file_open_or_merge(gboolean merge)
 {
     GtkWidget *dialog;
     GSList *filenames = NULL, *l;
-    gchar *name, *filename_utf8, *filename_sys;
-    const gchar *loaded_as = NULL;
-    GwyContainer *data;
+    gchar *name;
     gint response;
 
     dialog = _gwy_app_file_chooser_get(GTK_FILE_CHOOSER_ACTION_OPEN);
@@ -356,19 +369,6 @@ gwy_app_file_open_or_merge(gboolean merge)
 
     response = gtk_dialog_run(GTK_DIALOG(dialog));
     name = _gwy_app_file_chooser_get_selected_type(GWY_APP_FILE_CHOOSER(dialog));
-    /* This has to be called before hiding the dialog because hiding frees
-     * the previewed data */
-    _gwy_app_file_chooser_get_previewed_data(GWY_APP_FILE_CHOOSER(dialog),
-                                             &data,
-                                             &filename_utf8, &filename_sys);
-    if (data) {
-        g_object_ref(data);
-        gwy_debug("got %s data from preview", filename_utf8);
-        if (!gwy_file_get_data_info(data, &loaded_as, NULL)) {
-            g_warning("Cannot obtain previewed file type.");
-            loaded_as = name;
-        }
-    }
     if (response == GTK_RESPONSE_OK)
         filenames = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(dialog));
     gtk_widget_hide(dialog);
@@ -376,39 +376,23 @@ gwy_app_file_open_or_merge(gboolean merge)
     for (l = filenames; l; l = g_slist_next(l)) {
         gchar *fname_sys = (gchar*)l->data;
 
-        /* To force the file type the user insists on we have to avoid
-         * reusing previewed data. */
-        if (data
-            && gwy_strequal(filename_sys, fname_sys)
-            && (!name || gwy_strequal(name, loaded_as))) {
-            if (merge)
+        if (merge) {
+            GwyContainer *data;
+
+            data = gwy_app_file_load_real(NULL, fname_sys, name, FALSE);
+            if (data) {
                 gwy_app_data_browser_merge(data);
-            else
-                gwy_app_file_add_loaded(data, filename_utf8, filename_sys);
-
-            warn_broken_load_func(name, data);
-        }
-        else {
-            if (merge) {
-                GwyContainer *newdata;
-
-                newdata = gwy_app_file_load_real(NULL, fname_sys, name, FALSE);
-                if (newdata) {
-                    gwy_app_data_browser_merge(newdata);
-                    g_object_unref(newdata);
-                    warn_broken_load_func(name, newdata);
-                }
+                g_object_unref(data);
+                warn_broken_load_func(name, data);
             }
-            else
-                gwy_app_file_load(NULL, fname_sys, name);
         }
+        else
+            gwy_app_file_load(NULL, fname_sys, name);
+
         g_free(fname_sys);
     }
     g_slist_free(filenames);
     g_free(name);
-    gwy_object_unref(data);
-    g_free(filename_utf8);
-    g_free(filename_sys);
 }
 
 /*** File saving ***********************************************************/
@@ -483,7 +467,8 @@ gwy_app_file_write(GwyContainer *data,
             saveok = 0;
     }
     else
-        saveok = gwy_file_save(data, filename_sys, GWY_RUN_INTERACTIVE, &err);
+        saveok = gwy_file_save_with_func(data, filename_sys,
+                                         GWY_RUN_INTERACTIVE, &name, &err);
 
     switch (saveok) {
         case GWY_FILE_OPERATION_SAVE:
@@ -505,13 +490,26 @@ gwy_app_file_write(GwyContainer *data,
         if (err && !g_error_matches(err,
                                     GWY_MODULE_FILE_ERROR,
                                     GWY_MODULE_FILE_ERROR_CANCELLED)) {
+            gchar *filename_disp = g_filename_display_basename(filename_utf8);
+            GString *message = g_string_new(NULL);
+
             dialog = gtk_message_dialog_new(NULL, 0,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             _("Saving of `%s' failed"),
-                                            filename_utf8);
+                                            filename_disp);
+            g_free(filename_disp);
+            g_string_append(message, err->message);
+            g_string_append(message, "\n\n");
+            g_string_append_printf(message,
+                                   _("Full file path: %s."), filename_utf8);
+            if (name) {
+                g_string_append(message, "\n\n");
+                g_string_append_printf(message, _("Saved using: %s."), name);
+            }
             gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
-                                                     "%s", err->message);
+                                                     "%s", message->str);
+            g_string_free(message, TRUE);
             g_signal_connect(dialog, "response",
                              G_CALLBACK(gtk_widget_destroy), NULL);
             gtk_widget_show_all(dialog);
