@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyresource.c 8480 2007-08-25 14:24:17Z yeti-dn $
+ *  @(#) $Id: gwyresource.c 11744 2011-01-11 08:26:44Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -22,20 +22,9 @@
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
-
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif
-
-#if (defined(HAVE_SYS_STAT_H) || defined(_WIN32))
 #include <sys/stat.h>
-/* And now we are in a deep s... */
-#endif
-
-#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#endif
-
 #include <glib/gstdio.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwyenum.h>
@@ -552,9 +541,9 @@ gwy_resource_parse_real(const gchar *text,
                         gboolean is_const)
 {
     GwyResourceClass *klass;
-    GwyResource *resource;
+    GwyResource *resource = NULL;
     GType type;
-    gchar *name;
+    gchar *name = NULL;
     guint len;
 
     if (!g_str_has_prefix(text, MAGIC_HEADER)) {
@@ -568,7 +557,7 @@ gwy_resource_parse_real(const gchar *text,
     text = strchr(text + len, '\n');
     if (!text) {
         g_warning("Truncated resource header");
-        return NULL;
+        goto fail;
     }
     text++;
     type = g_type_from_name(name);
@@ -578,8 +567,7 @@ gwy_resource_parse_real(const gchar *text,
         || !G_TYPE_IS_INSTANTIATABLE(type)
         || G_TYPE_IS_ABSTRACT(type)) {
         g_warning("Wrong resource type `%s'", name);
-        g_free(name);
-        return NULL;
+        goto fail;
     }
     klass = GWY_RESOURCE_CLASS(g_type_class_peek_static(type));
     g_return_val_if_fail(klass && klass->parse, NULL);
@@ -587,6 +575,8 @@ gwy_resource_parse_real(const gchar *text,
     resource = klass->parse(text, is_const);
     if (resource)
         g_string_assign(resource->name, name);
+
+fail:
     g_free(name);
 
     return resource;
