@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwy3dwindow.c 9074 2009-03-15 13:49:22Z yeti-dn $
+ *  @(#) $Id: gwy3dwindow.c 12364 2011-05-03 15:26:08Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -632,7 +632,8 @@ gwy_3d_window_new(Gwy3DView *gwy3dview)
     /* Basic table */
     vbox = gwy_3d_window_build_basic_tab(gwy3dwindow);
     gtk_notebook_append_page(GTK_NOTEBOOK(gwy3dwindow->notebook),
-                             vbox, gtk_label_new(_("Basic")));
+                             vbox,
+                             gtk_label_new(gwy_sgettext("3dcontrols|Basic")));
 
     /* Light & Material table */
     vbox = gwy_3d_window_build_visual_tab(gwy3dwindow);
