@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphmodel.c 11752 2011-01-13 14:18:28Z yeti-dn $
+ *  @(#) $Id: gwygraphmodel.c 12434 2011-05-17 09:51:48Z klapetek $
  *  Copyright (C) 2004-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1659,8 +1659,9 @@ gwy_graph_model_export_ascii(GwyGraphModel *model,
         units = g_string_new(NULL);
         for (i = 0; i < model->curves->len; i++) {
             cmodel = g_ptr_array_index(model->curves, i);
-            if (export_metadata)
-                g_string_append_printf(descriptions, "%s;",
+            if (export_metadata) 
+                g_string_append_printf(descriptions, "%s;%s;",
+                                       cmodel->description->str,
                                        cmodel->description->str);
             if (export_labels)
                 g_string_append_printf(labels, "%s;%s;",
