@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymodule-file.h 10202 2009-10-05 08:28:28Z yeti-dn $
+ *  @(#) $Id: gwymodule-file.h 12482 2011-05-28 13:03:47Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -104,10 +104,19 @@ const gchar*        gwy_file_detect_with_score(const gchar *filename,
 GwyContainer*       gwy_file_load             (const gchar *filename,
                                                GwyRunType mode,
                                                GError **error);
+GwyContainer*       gwy_file_load_with_func   (const gchar *filename,
+                                               GwyRunType mode,
+                                               const gchar **name,
+                                               GError **error);
 GwyFileOperationType gwy_file_save            (GwyContainer *data,
                                                const gchar *filename,
                                                GwyRunType mode,
                                                GError **error);
+GwyFileOperationType gwy_file_save_with_func  (GwyContainer *data,
+                                               const gchar *filename,
+                                               GwyRunType mode,
+                                               const gchar **name,
+                                               GError **error);
 gboolean            gwy_file_func_get_is_detectable(const gchar *name);
 void                gwy_file_func_set_is_detectable(const gchar *name,
                                                     gboolean is_detectable);
