@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwymoduleloader.h 11582 2010-11-18 15:17:30Z yeti-dn $
+ *  @(#) $Id: gwymoduleloader.h 12365 2011-05-03 15:27:03Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -27,9 +27,15 @@ G_BEGIN_DECLS
 
 #define GWY_MODULE_ABI_VERSION 2
 
+#ifdef  __cplusplus
+#define __GWY_MODULE_QUERY_EXTERN_C extern "C"
+#else
+#define __GWY_MODULE_QUERY_EXTERN_C /* */
+#endif
+
 #define GWY_MODULE_QUERY(mod_info) \
-    G_MODULE_EXPORT GwyModuleInfo* \
-    _gwy_module_query(void) { return &mod_info; }
+    __GWY_MODULE_QUERY_EXTERN_C G_MODULE_EXPORT GwyModuleInfo* \
+    _gwy_module_query(void) { return &mod_info; } \
 
 #define GWY_MODULE_ERROR gwy_module_error_quark()
 
