@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyprocessenums.c 11541 2010-11-12 14:20:23Z yeti-dn $
+ *  @(#) $Id: gwyprocessenums.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -78,7 +78,7 @@ gwy_plane_symmetry_get_enum(void)
         { N_("Detected"),   GWY_SYMMETRY_AUTO       },
         { N_("Parallel"),   GWY_SYMMETRY_PARALLEL   },
         { N_("Triangular"), GWY_SYMMETRY_TRIANGULAR },
-        { N_("Square"),     GWY_SYMMETRY_SQUARE     },
+        { N_("symmetry|Square"),     GWY_SYMMETRY_SQUARE     },
         { N_("Rhombic"),    GWY_SYMMETRY_RHOMBIC    },
         { N_("Hexagonal"),  GWY_SYMMETRY_HEXAGONAL  },
         { NULL,             0,                      },
@@ -202,6 +202,7 @@ const GwyEnum*
 gwy_interpolation_type_get_enum(void)
 {
     static const GwyEnum entries[] = {
+        /* TRANSLATORS: Interpolation type (AKA nearest neighbour) */
         { N_("Round"),   GWY_INTERPOLATION_ROUND,   },
         { N_("Linear"),  GWY_INTERPOLATION_LINEAR,  },
         { N_("Key"),     GWY_INTERPOLATION_KEY,     },
@@ -240,17 +241,17 @@ const GwyEnum*
 gwy_windowing_type_get_enum(void)
 {
     static const GwyEnum entries[] = {
-        { N_("None"),       GWY_WINDOWING_NONE,      },
-        { N_("Hann"),       GWY_WINDOWING_HANN,      },
-        { N_("Hamming"),    GWY_WINDOWING_HAMMING,   },
-        { N_("Blackmann"),  GWY_WINDOWING_BLACKMANN, },
-        { N_("Lanzcos"),    GWY_WINDOWING_LANCZOS,   },
-        { N_("Welch"),      GWY_WINDOWING_WELCH,     },
-        { N_("Rect"),       GWY_WINDOWING_RECT,      },
-        { N_("Nuttall"),    GWY_WINDOWING_NUTTALL,   },
-        { N_("Flat-top"),   GWY_WINDOWING_FLAT_TOP,  },
-        { N_("Kaiser 2.5"), GWY_WINDOWING_KAISER25,  },
-        { NULL,             0,                       },
+        { N_("windowing|None"), GWY_WINDOWING_NONE,      },
+        { N_("Hann"),           GWY_WINDOWING_HANN,      },
+        { N_("Hamming"),        GWY_WINDOWING_HAMMING,   },
+        { N_("Blackmann"),      GWY_WINDOWING_BLACKMANN, },
+        { N_("Lanzcos"),        GWY_WINDOWING_LANCZOS,   },
+        { N_("Welch"),          GWY_WINDOWING_WELCH,     },
+        { N_("Rect"),           GWY_WINDOWING_RECT,      },
+        { N_("Nuttall"),        GWY_WINDOWING_NUTTALL,   },
+        { N_("Flat-top"),       GWY_WINDOWING_FLAT_TOP,  },
+        { N_("Kaiser 2.5"),     GWY_WINDOWING_KAISER25,  },
+        { NULL,                 0,                       },
     };
     return entries;
 }
@@ -259,10 +260,10 @@ const GwyEnum*
 gwy_correlation_type_get_enum(void)
 {
     static const GwyEnum entries[] = {
-        { N_("Normal"),      GWY_CORRELATION_NORMAL, },
-        { N_("FFT"),         GWY_CORRELATION_FFT,    },
-        { N_("Phase only"),  GWY_CORRELATION_POC,    },
-        { NULL,           0,                       },
+        { N_("correlation|Normal"), GWY_CORRELATION_NORMAL, },
+        { N_("FFT"),                GWY_CORRELATION_FFT,    },
+        { N_("Phase only"),         GWY_CORRELATION_POC,    },
+        { NULL,                     0,                      },
     };
     return entries;
 }
