@@ -1,5 +1,5 @@
 /*
- *  $Id: aistfile.c 11681 2010-12-10 07:56:23Z yeti-dn $
+ *  $Id: aistfile.c 12356 2011-05-02 07:17:14Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -603,7 +603,7 @@ read_qt_string(const guchar **p, gsize *size, gchar **value)
     }
     else if (G_BYTE_ORDER == G_LITTLE_ENDIAN) {
         utf16native = must_free = g_new(gunichar2, len/sizeof(gunichar2));
-        swab(*p, must_free, len);
+        swab(*p, (gpointer)must_free, len);
     }
     *value = g_utf16_to_utf8(utf16native, len/sizeof(gunichar2), NULL, NULL,
                              NULL);
