@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: err.h 11337 2010-06-29 12:27:24Z yeti-dn $
+ *  @(#) $Id: err.h 12362 2011-05-03 13:55:02Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -33,6 +33,20 @@ err_GET_FILE_CONTENTS(GError **error, GError **err)
     g_clear_error(err);
 }
 
+static inline void
+err_OPEN_READ(GError **error)
+{
+    g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_IO,
+                _("Cannot open file for reading: %s."), g_strerror(errno));
+}
+
+static inline void
+err_READ(GError **error)
+{
+    g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_IO,
+                _("Cannot read from file: %s."), g_strerror(errno));
+}
+
 static inline void
 err_OPEN_WRITE(GError **error)
 {
