@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwytiff.h 11325 2010-06-15 06:54:23Z yeti-dn $
+ *  @(#) $Id: gwytiff.h 12470 2011-05-26 13:22:39Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -59,7 +59,7 @@ typedef enum {
 } GwyTIFFDataType;
 
 /* Standard TIFF tags */
-enum {
+typedef enum {
     GWY_TIFFTAG_IMAGE_WIDTH       = 256,
     GWY_TIFFTAG_IMAGE_LENGTH      = 257,
     GWY_TIFFTAG_BITS_PER_SAMPLE   = 258,
@@ -76,6 +76,7 @@ enum {
     GWY_TIFFTAG_X_RESOLUTION      = 282,
     GWY_TIFFTAG_Y_RESOLUTION      = 283,
     GWY_TIFFTAG_PLANAR_CONFIG     = 284,
+    GWY_TIFFTAG_RESOLUTION_UNIT   = 296,
     GWY_TIFFTAG_SOFTWARE          = 305,
     GWY_TIFFTAG_DATE_TIME         = 306,
     GWY_TIFFTAG_ARTIST            = 315,
@@ -111,6 +112,12 @@ typedef enum {
     GWY_TIFF_PLANAR_CONFIG_SEPARATE = 2,
 } GwyTIFFPlanarConfig;
 
+typedef enum {
+    GWY_TIFF_RESOLUTION_UNIT_NONE = 0,
+    GWY_TIFF_RESOLUTION_UNIT_INCH = 1,
+    GWY_TIFF_RESOLUTION_UNIT_CENTIMETER = 2,
+} GwyTIFFResolutionUnit;
+
 typedef enum {
     GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER = 1,
     GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER = 2,
@@ -232,7 +239,7 @@ gwy_tiff_load_impl(GwyTIFF *tiff,
             GwyTIFFEntry entry;
 
             entry.tag = tiff->get_guint16(&p);
-            entry.type = tiff->get_guint16(&p);
+            entry.type = (GwyTIFFDataType)tiff->get_guint16(&p);
             entry.count = tiff->get_guint32(&p);
             memcpy(entry.value, p, 4);
             p += 4;
@@ -251,7 +258,7 @@ gwy_tiff_free(GwyTIFF *tiff)
         guint i;
 
         for (i = 0; i < tiff->dirs->len; i++)
-            g_array_free(g_ptr_array_index(tiff->dirs, i), TRUE);
+            g_array_free((GArray*)g_ptr_array_index(tiff->dirs, i), TRUE);
 
         g_ptr_array_free(tiff->dirs, TRUE);
     }
@@ -323,7 +330,7 @@ gwy_tiff_tags_valid(const GwyTIFF *tiff,
     guint i, j, offset, item_size;
 
     for (i = 0; i < tiff->dirs->len; i++) {
-        const GArray *tags = g_ptr_array_index(tiff->dirs, i);
+        const GArray *tags = (const GArray*)g_ptr_array_index(tiff->dirs, i);
 
         for (j = 0; j < tags->len; j++) {
             const GwyTIFFEntry *entry;
@@ -369,7 +376,8 @@ gwy_tiff_sort_tags(GwyTIFF *tiff)
     guint i;
 
     for (i = 0; i < tiff->dirs->len; i++)
-        g_array_sort(g_ptr_array_index(tiff->dirs, i), gwy_tiff_tag_compare);
+        g_array_sort((GArray*)g_ptr_array_index(tiff->dirs, i),
+                     gwy_tiff_tag_compare);
 }
 
 static const GwyTIFFEntry*
@@ -396,7 +404,7 @@ gwy_tiff_find_tag(const GwyTIFF *tiff,
     if (dirno >= tiff->dirs->len)
         return NULL;
 
-    tags = g_ptr_array_index(tiff->dirs, dirno);
+    tags = (const GArray*)g_ptr_array_index(tiff->dirs, dirno);
     lo = 0;
     hi = tags->len-1;
     while (hi - lo > 1) {
@@ -454,6 +462,59 @@ gwy_tiff_get_uint(const GwyTIFF *tiff,
     return TRUE;
 }
 
+G_GNUC_UNUSED static gboolean
+gwy_tiff_get_uints(const GwyTIFF *tiff,
+                   guint dirno,
+                   guint tag,
+                   guint expected_count,
+                   guint *retval)
+{
+    const GwyTIFFEntry *entry;
+    const guchar *p;
+    guint i, offset, size = 0;
+
+    entry = gwy_tiff_find_tag(tiff, dirno, tag);
+    if (!entry || entry->count != expected_count)
+        return FALSE;
+
+    p = entry->value;
+    if (entry->type == GWY_TIFF_BYTE)
+        size = expected_count;
+    else if (entry->type == GWY_TIFF_SHORT)
+        size = 2*expected_count;
+    else if (entry->type == GWY_TIFF_LONG)
+        size = 4*expected_count;
+    else
+        return FALSE;
+
+    if (size > 4) {
+        offset = tiff->get_guint32(&p);
+        p = tiff->data + offset;
+    }
+
+    for (i = 0; i < expected_count; i++) {
+        switch (entry->type) {
+            case GWY_TIFF_BYTE:
+            *(retval++) = *(p++);
+            break;
+
+            case GWY_TIFF_SHORT:
+            *(retval++) = tiff->get_guint16(&p);
+            break;
+
+            case GWY_TIFF_LONG:
+            *(retval++) = tiff->get_guint32(&p);
+            break;
+
+            default:
+            return FALSE;
+            break;
+        }
+    }
+
+    return TRUE;
+}
+
 G_GNUC_UNUSED static gboolean
 gwy_tiff_get_sint(const GwyTIFF *tiff,
                   guint dirno,
@@ -606,10 +667,12 @@ gwy_tiff_get_string(const GwyTIFF *tiff,
 G_GNUC_UNUSED static GwyTIFFImageReader*
 gwy_tiff_get_image_reader(const GwyTIFF *tiff,
                           guint dirno,
+                          guint max_samples,
                           GError **error)
 {
     GwyTIFFImageReader reader;
     guint nstripes, i, ssize;
+    guint *bps;
 
     reader.dirno = dirno;
 
@@ -629,13 +692,34 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
         return NULL;
     }
 
-    /* The TIFF specs say these are required, but they seem to default to 1. */
-    if (!gwy_tiff_get_uint(tiff, dirno, GWY_TIFFTAG_BITS_PER_SAMPLE,
-                           &reader.bits_per_sample))
-        reader.bits_per_sample = 1;
+    /* The TIFF specs say this is required, but it seems to default to 1. */
     if (!gwy_tiff_get_uint(tiff, dirno, GWY_TIFFTAG_SAMPLES_PER_PIXEL,
                            &reader.samples_per_pixel))
         reader.samples_per_pixel = 1;
+    if (reader.samples_per_pixel == 0
+        || reader.samples_per_pixel > max_samples) {
+        err_UNSUPPORTED(error, "SamplesPerPixel");
+        return NULL;
+    }
+
+    /* The TIFF specs say this is required, but it seems to default to 1. */
+    bps = g_new(guint, reader.samples_per_pixel);
+    if (!gwy_tiff_get_uints(tiff, dirno, GWY_TIFFTAG_BITS_PER_SAMPLE,
+                            reader.samples_per_pixel, bps))
+        reader.bits_per_sample = 1;
+    else {
+        for (i = 1; i < reader.samples_per_pixel; i++) {
+            if (bps[i] != bps[i-1]) {
+                g_set_error(error, GWY_MODULE_FILE_ERROR,
+                            GWY_MODULE_FILE_ERROR_DATA,
+                            _("Non-uniform bits per sample are unsupported."));
+                g_free(bps);
+                return NULL;
+            }
+        }
+        reader.bits_per_sample = bps[0];
+    }
+    g_free(bps);
 
     /* The TIFF specs say this is required, but it seems to default to
      * MAXINT.  Setting more reasonably to RowsPerStrip = ImageLength achieves
@@ -647,7 +731,8 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
     /*
      * The data sample type (default is unsigned integer)
      */
-    if (!gwy_tiff_get_uint(tiff, dirno, GWY_TIFFTAG_SAMPLE_FORMAT, &reader.sample_format))
+    if (!gwy_tiff_get_uint(tiff, dirno, GWY_TIFFTAG_SAMPLE_FORMAT,
+                           &reader.sample_format))
         reader.sample_format = GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER;
 
     /* Integer fields specifying data in a format we do not support */
@@ -663,21 +748,19 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
                     _("Planar configuration %u is not supported."), i);
         return NULL;
     }
-    if (reader.bits_per_sample != 16 && reader.bits_per_sample != 32) {
+    if (reader.bits_per_sample != 8
+        && reader.bits_per_sample != 16
+        && reader.bits_per_sample != 32) {
         err_BPP(error, reader.bits_per_sample);
         return NULL;
     }
     if (reader.sample_format != GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER
-        &&  reader.sample_format != GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
+        && reader.sample_format != GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                     _("Unsupported sample format"));
         return NULL;
     }
 
-    if (reader.samples_per_pixel != 1) {
-        err_UNSUPPORTED(error, "SamplesPerPixel");
-        return NULL;
-    }
     if (reader.stripe_rows == 0 || reader.stripe_rows > reader.width) {
         err_INVALID(error, "RowsPerStripe");
         return NULL;
@@ -745,46 +828,65 @@ gwy_tiff_get_image_reader(const GwyTIFF *tiff,
     }
 
     /* If we got here we are convinced we can read the image data. */
-    return g_memdup(&reader, sizeof(GwyTIFFImageReader));
+    return (GwyTIFFImageReader*)g_memdup(&reader, sizeof(GwyTIFFImageReader));
 }
 
 G_GNUC_UNUSED static inline void
 gwy_tiff_read_image_row(const GwyTIFF *tiff,
                         const GwyTIFFImageReader *reader,
+                        guint channelno,
                         guint rowno,
                         gdouble q,
                         gdouble z0,
                         gdouble *dest)
 {
+    GwyTIFFSampleFormat sformat = (GwyTIFFSampleFormat)reader->sample_format;
     const guchar *p;
-    guint stripeno, stripeindex, i;
+    guint stripeno, stripeindex, i, skip;
 
     g_return_if_fail(reader->dirno < tiff->dirs->len);
     g_return_if_fail(rowno < reader->height);
+    g_return_if_fail(channelno < reader->samples_per_pixel);
 
     stripeno = rowno/reader->stripe_rows;
     stripeindex = rowno % reader->stripe_rows;
-    p = tiff->data + reader->offsets[stripeno] + stripeindex*reader->rowstride;
+    p = tiff->data + (reader->offsets[stripeno] + stripeindex*reader->rowstride
+                      + (reader->bits_per_sample/8)*channelno);
 
     switch (reader->bits_per_sample) {
+        case 8:
+        skip = reader->samples_per_pixel;
+        if (sformat == GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER) {
+            for (i = 0; i < reader->width; i++, p += skip)
+                dest[i] = z0 + q*(*p);
+        }
+        else if (sformat == GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
+            const gchar *s = (const gchar*)p;
+            for (i = 0; i < reader->width; i++, s += skip)
+                dest[i] = z0 + q*(*s);
+        }
+        break;
+
         case 16:
-        if (reader->sample_format == GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER) {
-            for (i = 0; i < reader->width; i++)
+        skip = (reader->samples_per_pixel - 1)*reader->bits_per_sample;
+        if (sformat == GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER) {
+            for (i = 0; i < reader->width; i++, p += skip)
                 dest[i] = z0 + q*tiff->get_guint16(&p);
         }
-        else if (reader->sample_format == GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
-            for (i = 0; i < reader->width; i++)
+        else if (sformat == GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
+            for (i = 0; i < reader->width; i++, p += skip)
                 dest[i] = z0 + q*tiff->get_gint16(&p);
         }
         break;
 
         case 32:
-        if (reader->sample_format == GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER) {
-            for (i = 0; i < reader->width; i++)
+        skip = (reader->samples_per_pixel - 1)*reader->bits_per_sample;
+        if (sformat == GWY_TIFF_SAMPLE_FORMAT_UNSIGNED_INTEGER) {
+            for (i = 0; i < reader->width; i++, p += skip)
                 dest[i] = z0 + q*tiff->get_guint32(&p);
         }
-        else if (reader->sample_format == GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
-            for (i = 0; i < reader->width; i++)
+        else if (sformat == GWY_TIFF_SAMPLE_FORMAT_SIGNED_INTEGER) {
+            for (i = 0; i < reader->width; i++, p += skip)
                 dest[i] = z0 + q*tiff->get_gint32(&p);
         }
         break;
@@ -796,7 +898,7 @@ gwy_tiff_read_image_row(const GwyTIFF *tiff,
 }
 
 /* Idempotent, use: reader = gwy_tiff_image_reader_free(reader); */
-G_GNUC_UNUSED static inline gpointer
+G_GNUC_UNUSED static inline GwyTIFFImageReader*
 gwy_tiff_image_reader_free(GwyTIFFImageReader *reader)
 {
     if (reader) {
