@@ -1,5 +1,5 @@
 /*
- *  $Id: mulfile.c 12263 2011-04-06 17:53:42Z yeti-dn $
+ *  $Id: mulfile.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2011 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -160,7 +160,7 @@ static gboolean
 module_register(void)
 {
     gwy_file_func_register("mulfile",
-                           N_("Aarhus NUL files (.mul)"),
+                           N_("Aarhus MUL files (.mul)"),
                            (GwyFileDetectFunc)&mul_detect,
                            (GwyFileLoadFunc)&mul_load,
                            NULL,
