@@ -1,5 +1,5 @@
 /*
- *  $Id: nanoeducator.c 12271 2011-04-07 19:43:19Z dn2010 $
+ *  $Id: nanoeducator.c 12300 2011-04-16 14:45:57Z dn2010 $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -270,6 +270,7 @@ static GwySpectra*    nanoedu_read_iz_spectra(const guchar *pos_buffer,
                                               gdouble yreal,
                                               gdouble xscale,
                                               gdouble yscale,
+                                              gint sp_type,
                                               GError **error);
 static GwyContainer* nanoedu_read_meta       (const NanoeduFileHeader *header,
                                               const NanoeduParameterHeader *param);
@@ -474,8 +475,9 @@ nanoedu_load(const gchar *filename,
                                               Nanometer*q, scale*header.topo_ny,
                                               Nanometer*qx, Nanometer*qy,
                                               error);
-        else if (size - header.spec_offset
-            == 4 * params.n_spectra_lines * params.n_spectrum_points)
+        else if ((params.spectroscopy_type == 1)
+              || (size - header.spec_offset
+              == 4 * params.n_spectra_lines * params.n_spectrum_points))
             spectra = nanoedu_read_iz_spectra(buffer + header.point_offset,
                                               header.spec_offset - header.point_offset,
                                               buffer + header.spec_offset,
@@ -484,6 +486,7 @@ nanoedu_load(const gchar *filename,
                                               params.n_spectrum_points,
                                               Nanometer*q, scale*header.topo_ny,
                                               Nanometer*qx, Nanometer*qy,
+                                              params.spectroscopy_type,
                                               error);
         else
             spectra = nanoedu_read_iv_spectra(buffer + header.point_offset,
@@ -1156,7 +1159,7 @@ make_iz_spectrum(gint res, gdouble xy_step,
     g_object_unref(siunity);
 
     data = gwy_data_line_get_data(dline);
-    /* XXX: The odd coordinates are abscissas.  We use the zeroth and last 
+    /* XXX: The odd coordinates are abscissas.  We use the zeroth and last
      * for x offset and scale. If they are not equidistant, though luck... */
     for (j = 0; j < res; j++) {
         v = d16[2*j];
@@ -1173,6 +1176,7 @@ nanoedu_read_iz_spectra(const guchar *pos_buffer, gsize pos_size,
                         gint nspectra, gint res,
                         gdouble xy_step, gdouble yreal,
                         gdouble xscale, gdouble yscale,
+                        gint sp_type,
                         GError **error)
 {
     gint i, j, n, pointstep;
@@ -1203,13 +1207,30 @@ nanoedu_read_iz_spectra(const guchar *pos_buffer, gsize pos_size,
         gwy_debug("IZ spec%d [%g,%g] %dpts", i, x, y, n);
 
         for(j = 0; j < n; j++) {
-            /* Only one direction */
-            dline = make_iz_spectrum(res, xy_step,
-                                     d16 + 2*(i*n+j)*res,
-                                     1e-12);
-            data = gwy_data_line_get_data(dline);
-            gwy_spectra_add_spectrum(spectra, dline, x, y);
-            g_object_unref(dline);
+            if (1 == sp_type) {
+                /* two directions in new format */
+                dline = make_iz_spectrum(res, xy_step,
+                                        d16 + 4*(i*n+j)*res,
+                                        1e-12);
+                data = gwy_data_line_get_data(dline);
+                gwy_spectra_add_spectrum(spectra, dline, x, y);
+                g_object_unref(dline);
+                dline = make_iz_spectrum(res, xy_step,
+                                         d16 + 4*(i*n+j)*res + 2*res,
+                                         1e-12);
+                data = gwy_data_line_get_data(dline);
+                gwy_spectra_add_spectrum(spectra, dline, x, y);
+                g_object_unref(dline);
+            }
+            else {
+                /* one direction */
+                dline = make_iz_spectrum(res, xy_step,
+                                        d16 + 2*(i*n+j)*res,
+                                        1e-12);
+                data = gwy_data_line_get_data(dline);
+                gwy_spectra_add_spectrum(spectra, dline, x, y);
+                g_object_unref(dline);
+            }
         }
     }
 
