@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: nanoscope.c 11355 2010-07-10 12:33:13Z yeti-dn $
+ *  @(#) $Id: nanoscope.c 12440 2011-05-19 12:49:19Z yeti-dn $
  *  Copyright (C) 2004-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -129,7 +129,7 @@ static GwyGraphModel*  hash_to_curve          (GHashTable *hash,
                                                gchar *buffer,
                                                gint gxres,
                                                GError **error);
-static gboolean        read_text_data         (gint n,
+static gboolean        read_text_data         (guint n,
                                                gdouble *data,
                                                gchar **buffer,
                                                gint bpp,
@@ -686,6 +686,8 @@ get_physical_scale(GHashTable *hash,
         }
 
         /* Old style scales */
+        gwy_debug("Old-style scale, using hard units %g %s",
+                  val->hard_value, val->hard_value_units);
         siunit = gwy_si_unit_new_parse(val->hard_value_units, &q);
         *scale = val->hard_value * pow10(q);
         return siunit;
@@ -705,8 +707,11 @@ get_physical_scale(GHashTable *hash,
         }
 
         *scale = val->hard_value*sval->hard_value;
+        gwy_debug("Hard-value scale %g (%g * %g)",
+                  *scale, val->hard_value, sval->hard_value);
 
         if (!sval->hard_value_units || !*sval->hard_value_units) {
+            gwy_debug("No hard value units");
             if (gwy_strequal(val->soft_scale, "Sens. Phase"))
                 siunit = gwy_si_unit_new("deg");
             else
@@ -730,6 +735,8 @@ get_physical_scale(GHashTable *hash,
     else {
         /* We have '@2:Z scale' but the reference to soft scale is missing,
          * the quantity is something in the hard units (seen for Potential). */
+        gwy_debug("No soft scale, using hard units %g %s",
+                  val->hard_value, val->hard_value_units);
         siunit = gwy_si_unit_new_parse(val->hard_value_units, &q);
         *scale = val->hard_value * pow10(q);
     }
@@ -968,12 +975,12 @@ get_tuna_physical_scale(GHashTable *hash,
 }
 
 static gboolean
-read_text_data(gint n, gdouble *data,
+read_text_data(guint n, gdouble *data,
                gchar **buffer,
                gint bpp,
                GError **error)
 {
-    gint i;
+    guint i;
     gdouble q;
     gchar *end;
     long l, min, max;
@@ -990,7 +997,7 @@ read_text_data(gint n, gdouble *data,
         if (end == *buffer) {
             g_set_error(error, GWY_MODULE_FILE_ERROR,
                         GWY_MODULE_FILE_ERROR_DATA,
-                        _("Garbage after data sample #%d."), i);
+                        _("Garbage after data sample #%u."), i);
             return FALSE;
         }
         *buffer = end;
