@@ -1,6 +1,6 @@
 /*
- *  $Id: omicron.c 11241 2010-02-25 15:07:03Z yeti-dn $
- *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
+ *  $Id: omicron.c 12492 2011-05-30 20:59:42Z yeti-dn $
+ *  Copyright (C) 2006-2011 David Necas (Yeti), Petr Klapetek, Markus Pristovsek
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net,
  *  prissi@gift.physik.tu-berlin.de.
  *
@@ -137,6 +137,9 @@ static GwyDataField* omicron_read_data          (OmicronFile *ofile,
 static GwySpectra*   omicron_read_cs_data       (OmicronFile *ofile,
                                                  OmicronSpectroChannel *channel,
                                                  GError **error);
+static GwySpectra*   omicron_read_be_data       (OmicronFile *ofile,
+                                                 OmicronSpectroChannel *channel,
+                                                 GError **error);
 static GwyContainer* omicron_make_meta          (OmicronFile *ofile);
 static void          omicron_file_free          (OmicronFile *ofile);
 
@@ -145,7 +148,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Omicron data files (two-part .par + .tf*, .tb*, .sf*, .sb*)."),
     "Yeti <yeti@gwyddion.net>",
-    "0.7",
+    "0.8",
     "David Nečas (Yeti) & Petr Klapetek & Markus Pristovsek",
     "2006",
 };
@@ -324,7 +327,28 @@ omicron_load(const gchar *filename,
             }
             else if (omicron_has_extension(channel->filename, "sf")
                      || omicron_has_extension(channel->filename, "sb")) {
+                gchar *t;
+                GQuark quark;
+
+                spectra = omicron_read_be_data(&ofile, channel, error);
+                if (!spectra) {
+                    gwy_object_unref(container);
+                    goto fail;
+                }
+
+                if (!gwy_spectra_get_n_spectra(spectra)) {
+                    gwy_debug("Spectra %u is empty, ignoring", i);
+                    g_object_unref(spectra);
+                    continue;
+                }
+
                 /* FIXME */
+                t = g_strconcat(channel->chan, "-", channel->param, NULL);
+                gwy_spectra_set_title(spectra, t);
+                g_free(t);
+                quark = gwy_app_get_spectra_key_for_id(i);
+                gwy_container_set_object(container, quark, spectra);
+                g_object_unref(spectra);
             }
             else {
                 g_warning("Cannot determine spectra type of %s",
@@ -340,11 +364,12 @@ fail:
     return container;
 }
 
+/* XXX: The return value sometimes means FALSE, sometimes NULL. */
 #define GET_FIELD(hash, val, field, err) \
     do { \
         if (!(val = g_hash_table_lookup(hash, field))) { \
             err_MISSING_FIELD(err, field); \
-            return FALSE; \
+            return 0; \
         } \
     } while (FALSE)
 
@@ -934,6 +959,121 @@ omicron_read_cs_data(OmicronFile *ofile,
     return spectra;
 }
 
+/* Read grid spectra. */
+static GwySpectra*
+omicron_read_be_data(OmicronFile *ofile,
+                     OmicronSpectroChannel *channel,
+                     GError **error)
+{
+    gdouble xreal = channel->end - channel->start,
+            q = (channel->max_phys - channel->min_phys)
+                /(channel->max_raw - channel->min_raw),
+            z0 = channel->min_phys;
+    GError *err = NULL;
+    GwySIUnit *siunit = NULL, *coord_unit = NULL;
+    GwySpectra *spectra = NULL;
+    gsize size;
+    gchar *filename;
+    guchar *buffer;
+    guint i, j;
+    gint power10 = 0;
+    guint gxres, gyres, gxstep, gystep;
+    gchar* value;
+
+    GET_FIELD(ofile->meta, value, "Spectroscopy Points in X", error);
+    gxres = abs(atoi(value));
+    GET_FIELD(ofile->meta, value, "Spectroscopy Lines in Y", error);
+    gyres = abs(atoi(value));
+    GET_FIELD(ofile->meta, value, "Spectroscopy Grid Value in X", error);
+    gxstep = abs(atoi(value));
+    GET_FIELD(ofile->meta, value, "Spectroscopy Grid Value in Y", error);
+    gystep = abs(atoi(value));
+    gwy_debug("grid: %ux%u with steps %u,%u", gxres, gyres, gxstep, gystep);
+
+    filename = omicron_fix_file_name(ofile->filename, channel->filename, error);
+    if (!filename)
+        return NULL;
+
+    gwy_debug("Succeeded with <%s>", filename);
+    if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
+        g_free(filename);
+        err_GET_FILE_CONTENTS(error, &err);
+        return NULL;
+    }
+    g_free(filename);
+
+    if (err_SIZE_MISMATCH(error, 2*gxres*gyres*channel->npoints, size, TRUE)) {
+        gwy_file_abandon_contents(buffer, size, NULL);
+        return NULL;
+    }
+
+    spectra = gwy_spectra_new();
+
+    coord_unit = gwy_si_unit_new("m");
+    gwy_spectra_set_si_unit_xy(spectra, coord_unit);
+    g_object_unref(coord_unit);
+
+    for (i = 0; i < gyres; i++) {
+        gdouble y = ofile->yreal*gystep*(ofile->yres-1 - i)/gyres;
+        for (j = 0; j < gxres; j++) {
+            gdouble x = ofile->xreal*gxstep*j/gxres;
+            GwyDataLine *dline = gwy_data_line_new(channel->npoints, xreal,
+                                                   FALSE);
+
+            gwy_data_line_set_offset(dline, channel->start);
+            gwy_convert_raw_data(buffer + 2*(i*gxres + j), channel->npoints,
+                                 gxres*gyres,
+                                 GWY_RAW_DATA_SINT16,
+                                 GWY_BYTE_ORDER_BIG_ENDIAN,
+                                 gwy_data_line_get_data(dline), q, z0);
+
+            /* Set Units for the parameter (x) axis */
+            if ((channel->param[0] == 'V') || (channel->param[0] == 'E')) {
+                siunit = gwy_si_unit_new("V");
+                power10 = 0;
+            }
+            else if (channel->param[0] == 'I')
+                siunit = gwy_si_unit_new_parse("nA", &power10);
+            else if (channel->param[0] == 'Z')
+                siunit = gwy_si_unit_new_parse("nm", &power10);
+            else {
+                gwy_debug("Parameter unit not recognised");
+            }
+
+            if (siunit) {
+                gwy_data_line_set_si_unit_x(dline, siunit);
+                g_object_unref(siunit);
+            }
+
+            if (power10) {
+                gdouble offset = 0;
+                gdouble realsize = 0;
+
+                offset = gwy_data_line_get_offset(dline)*pow10(power10);
+                realsize = gwy_data_line_get_real(dline)*pow10(power10);
+
+                gwy_data_line_set_offset(dline, offset);
+                gwy_data_line_set_real(dline, realsize);
+            }
+
+            /* Set Units for the Value (y) Axis */
+            siunit = gwy_si_unit_new_parse(channel->units, &power10);
+            gwy_data_line_set_si_unit_y(dline, siunit);
+            g_object_unref(siunit);
+
+            if (power10)
+                gwy_data_line_multiply(dline, pow10(power10));
+
+            gwy_spectra_add_spectrum(spectra, dline, x, y);
+            gwy_debug("[%u,%u] %g, %g", j, i, x, y);
+            g_object_unref(dline);
+        }
+    }
+
+    return spectra;
+}
+
+
 static void
 add_meta(gpointer key, gpointer value, gpointer user_data)
 {
