@@ -1,5 +1,5 @@
 /*
- *  $Id: opdfile.c 12231 2011-03-20 22:32:00Z yeti-dn $
+ *  $Id: opdfile.c 12382 2011-05-09 22:52:36Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -402,6 +402,14 @@ get_block(OPDBlock *block, const guchar **p)
     block->type = gwy_get_guint16_le(p);
     block->size = gwy_get_guint32_le(p);
     block->flags = gwy_get_guint16_le(p);
+
+    if (strncmp(block->name, "AdjustVSI_", sizeof("AdjustVSI_")-1) == 0
+        && block->type == 7
+        && block->size == 2) {
+        g_warning("Changing the type of field %s from float to short.",
+                  block->name);
+        block->type = 6;
+    }
 }
 
 static gboolean
