@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: graph_fit.c 9046 2009-03-10 12:12:18Z yeti-dn $
+ *  @(#) $Id: graph_fit.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2003-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -255,11 +255,11 @@ fit_dialog(FitArgs *args)
     controls.dialog = dialog;
     gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
     gtk_dialog_add_action_widget(GTK_DIALOG(dialog),
-                                 gwy_stock_like_button_new(_("_Fit"),
+                                 gwy_stock_like_button_new(gwy_sgettext("verb|_Fit"),
                                                            GTK_STOCK_EXECUTE),
                                  RESPONSE_FIT);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
-                          _("_Estimate"), RESPONSE_ESTIMATE);
+                          gwy_sgettext("verb|_Estimate"), RESPONSE_ESTIMATE);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
                           _("_Plot Inits"), RESPONSE_PLOT);
     gtk_dialog_add_button(GTK_DIALOG(dialog),
@@ -713,8 +713,8 @@ fit_plot_curve(FitArgs *args)
     g_object_set(cmodel,
                  "description",
                  initial
-                 ? gwy_sgettext("noun|Estimate")
-                 : gwy_sgettext("noun|Fit"),
+                 ? gwy_sgettext("Estimate")
+                 : gwy_sgettext("Fit"),
                  NULL);
     gwy_graph_curve_model_set_data(cmodel, xd, yd, n);
 }
