@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: calibrate.c 11854 2011-01-25 07:11:03Z yeti-dn $
+ *  @(#) $Id: calibrate.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -336,7 +336,7 @@ calibrate_dialog(CalibrateArgs *args,
     gtk_table_attach(GTK_TABLE(table), controls.xyexponent, 2, 3, row, row+2,
                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
-    controls.xyunits = gtk_button_new_with_label(_("Change"));
+    controls.xyunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.xyunits), "id", (gpointer)"xy");
     gtk_table_attach(GTK_TABLE(table), controls.xyunits,
                      3, 4, row, row+2,
@@ -417,7 +417,7 @@ calibrate_dialog(CalibrateArgs *args,
     gtk_table_attach(GTK_TABLE(table), controls.zexponent, 2, 3, row, row+1,
                      GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 
-    controls.zunits = gtk_button_new_with_label(_("Change"));
+    controls.zunits = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     g_object_set_data(G_OBJECT(controls.zunits), "id", (gpointer)"z");
     gtk_table_attach(GTK_TABLE(table), controls.zunits,
                      3, 4, row, row+1,
