@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: convolution_filter.c 10297 2009-10-26 19:27:45Z yeti-dn $
+ *  @(#) $Id: convolution_filter.c 12332 2011-04-28 19:46:16Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -126,9 +126,9 @@ static void convolution_filter_save_args        (GwyContainer *settings,
                                                  ConvolutionArgs *args);
 
 static const GwyEnum symmetries[] = {
-    { N_("None"), CONVOLUTION_FILTER_SYMMETRY_NONE, },
-    { N_("Even"), CONVOLUTION_FILTER_SYMMETRY_EVEN, },
-    { N_("Odd"),  CONVOLUTION_FILTER_SYMMETRY_ODD,  },
+    { N_("symmetry|None"), CONVOLUTION_FILTER_SYMMETRY_NONE, },
+    { N_("symmetry|Even"), CONVOLUTION_FILTER_SYMMETRY_EVEN, },
+    { N_("symmetry|Odd"),  CONVOLUTION_FILTER_SYMMETRY_ODD,  },
 };
 
 static GwyModuleInfo module_info = {
