@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: dimensions.h 11486 2010-11-01 10:02:03Z yeti-dn $
+ *  @(#) $Id: dimensions.h 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2009 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -156,7 +156,7 @@ gwy_dimensions_make_units(GtkTable *table,
     gwy_sensitivity_group_add_widget(sensgroup, *combo, GWY_DIMENSIONS_SENS);
     gtk_table_attach(table, *combo, 1, 2, row, row+1, GTK_FILL, 0, 0, 0);
 
-    changer = gtk_button_new_with_label(_("Change"));
+    changer = gtk_button_new_with_label(gwy_sgettext("verb|Change"));
     gwy_sensitivity_group_add_widget(sensgroup, changer, GWY_DIMENSIONS_SENS);
     gtk_table_attach(table, changer, 2, 3, row, row+1, GTK_FILL, 0, 0, 0);
 
@@ -207,7 +207,7 @@ gwy_dimensions_units_changed(GtkWidget *widget,
     gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 
     entry = GTK_ENTRY(gtk_entry_new());
-    gtk_entry_set_text(entry, *unitstr);
+    gtk_entry_set_text(entry, *unitstr ? *unitstr : "");
     gtk_label_set_mnemonic_widget(GTK_LABEL(label), GTK_WIDGET(entry));
     gtk_entry_set_activates_default(entry, TRUE);
     gtk_box_pack_start(GTK_BOX(hbox), GTK_WIDGET(entry), TRUE, TRUE, 0);
