@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: edge.c 10297 2009-10-26 19:27:45Z yeti-dn $
+ *  @(#) $Id: edge.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2003-2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -694,7 +694,7 @@ zero_crossing_dialog(ZeroCrossingArgs *args,
     gtk_table_set_row_spacing(GTK_TABLE(table), row, 8);
     row++;
 
-    label = gtk_label_new(_("Display"));
+    label = gtk_label_new(gwy_sgettext("verb|Display"));
     gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
     gtk_table_attach(GTK_TABLE(table), label,
                      0, 3, row, row+1, GTK_FILL, 0, 0, 0);
