@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: immerse.c 10297 2009-10-26 19:27:45Z yeti-dn $
+ *  @(#) $Id: immerse.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -364,7 +364,8 @@ immerse_dialog(ImmerseArgs *args)
         = gwy_radio_buttons_createl(G_CALLBACK(immerse_leveling_changed),
                                     &controls,
                                     args->leveling,
-                                    _("_None"), GWY_IMMERSE_LEVEL_NONE,
+                                    gwy_sgettext("levelling|_None"),
+                                    GWY_IMMERSE_LEVEL_NONE,
                                     _("_Mean value"), GWY_IMMERSE_LEVEL_MEAN,
                                     NULL);
 
