@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: indent_analyze.c 12243 2011-03-27 14:15:54Z yeti-dn $
+ *  @(#) $Id: indent_analyze.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2006 Lukas Chvatal, David Necas (Yeti), Petr Klapetek.
  *  E-mail: chvatal@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -276,7 +276,7 @@ GwyEnum how_mark_enum[] = {
 GwyEnum what_mark_enum[] = {
     { N_("Nothing"),        GWY_WHAT_MARK_NOTHING     },
     { N_("Above"),          GWY_WHAT_MARK_ABOVE       },
-    { N_("Bellow"),         GWY_WHAT_MARK_BELOW       },
+    { N_("Below"),          GWY_WHAT_MARK_BELOW       },
     { N_("Plane"),          GWY_WHAT_MARK_PLANE       },
     { N_("Impression"),     GWY_WHAT_MARK_INDENTATION },
     { N_("Inner Pile-up"),  GWY_WHAT_MARK_INNERPILEUP },
