@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level.c 8872 2008-12-28 12:15:47Z yeti-dn $
+ *  @(#) $Id: level.c 10297 2009-10-26 19:27:45Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -38,12 +38,12 @@ typedef enum {
 } LevelMethod;
 
 typedef struct {
-    GwyMaskingType level_mode;
+    GwyMaskingType masking;
 } LevelArgs;
 
 typedef struct {
     LevelArgs *args;
-    GSList *mode;
+    GSList *masking;
 } LevelControls;
 
 static gboolean  module_register     (void);
@@ -63,7 +63,7 @@ static void      zero_mean           (GwyContainer *data,
 
 static gboolean  level_dialog        (LevelArgs *args,
                                       const gchar *title);
-static void      mode_changed_cb     (G_GNUC_UNUSED GObject *unused,
+static void      masking_changed     (GtkToggleButton *button,
                                       LevelControls *controls);
 static void      level_load_args     (GwyContainer *container, LevelArgs *args);
 static void      level_save_args     (GwyContainer *container, LevelArgs *args);
@@ -78,7 +78,7 @@ static GwyModuleInfo module_info = {
     N_("Levels data by simple plane subtraction or by rotation, "
        "and fixes minimal or mean value to zero."),
     "Yeti <yeti@gwyddion.net>",
-    "1.6",
+    "1.7",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -160,13 +160,13 @@ do_level(GwyContainer *data,
             return;
     }
     if (!mfield)
-        args.level_mode = GWY_MASK_IGNORE;
+        args.masking = GWY_MASK_IGNORE;
 
-    if (args.level_mode == GWY_MASK_IGNORE)
+    if (args.masking == GWY_MASK_IGNORE)
         mfield = NULL;
     if (mfield)
         mfield = gwy_data_field_duplicate(mfield);
-    if (mfield && args.level_mode == GWY_MASK_EXCLUDE) {
+    if (mfield && args.masking == GWY_MASK_EXCLUDE) {
         gwy_data_field_multiply(mfield, -1.0);
         gwy_data_field_add(mfield, 1.0);
     }
@@ -243,12 +243,6 @@ level_dialog(LevelArgs *args,
              const gchar *title)
 {
     enum { RESPONSE_RESET = 1 };
-    static const GwyEnum modes[] = {
-        { N_("_Exclude region under mask"),      GWY_MASK_EXCLUDE, },
-        { N_("Exclude region _outside mask"),    GWY_MASK_INCLUDE, },
-        { N_("Use entire _image (ignore mask)"), GWY_MASK_IGNORE,  },
-    };
-
     GtkWidget *dialog, *label, *table;
     gint row, response;
     LevelControls controls;
@@ -275,10 +269,10 @@ level_dialog(LevelArgs *args,
                      0, 3, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
     row++;
 
-    controls.mode = gwy_radio_buttons_create(modes, G_N_ELEMENTS(modes),
-                                             G_CALLBACK(mode_changed_cb),
-                                             &controls, args->level_mode);
-    row = gwy_radio_buttons_attach_to_table(controls.mode, GTK_TABLE(table),
+    controls.masking = gwy_radio_buttons_create(gwy_masking_type_get_enum(), -1,
+                                                G_CALLBACK(masking_changed),
+                                                &controls, args->masking);
+    row = gwy_radio_buttons_attach_to_table(controls.masking, GTK_TABLE(table),
                                             3, row);
 
     gtk_widget_show_all(dialog);
@@ -298,7 +292,7 @@ level_dialog(LevelArgs *args,
 
             case RESPONSE_RESET:
             *args = level_defaults;
-            gwy_radio_buttons_set_current(controls.mode, args->level_mode);
+            gwy_radio_buttons_set_current(controls.masking, args->masking);
             break;
 
             default:
@@ -313,27 +307,30 @@ level_dialog(LevelArgs *args,
 }
 
 static void
-mode_changed_cb(G_GNUC_UNUSED GObject *unused, LevelControls *controls)
+masking_changed(GtkToggleButton *button, LevelControls *controls)
 {
-    controls->args->level_mode = gwy_radio_buttons_get_current(controls->mode);
+    if (!gtk_toggle_button_get_active(button))
+        return;
+
+    controls->args->masking = gwy_radio_buttons_get_current(controls->masking);
 }
 
-static const gchar level_mode_key[] = "/module/level/mode";
+static const gchar masking_key[] = "/module/level/mode";
 
 static void
 level_load_args(GwyContainer *container, LevelArgs *args)
 {
     *args = level_defaults;
 
-    gwy_container_gis_enum_by_name(container, level_mode_key,
-                                   &args->level_mode);
+    gwy_container_gis_enum_by_name(container, masking_key,
+                                   &args->masking);
 }
 
 static void
 level_save_args(GwyContainer *container, LevelArgs *args)
 {
-    gwy_container_set_enum_by_name(container, level_mode_key,
-                                   args->level_mode);
+    gwy_container_set_enum_by_name(container, masking_key,
+                                   args->masking);
 }
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
