@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: merge.c 7587 2007-02-27 21:00:36Z klapetek $
+ *  @(#) $Id: merge.c 12393 2011-05-11 07:57:09Z yeti-dn $
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -124,15 +124,15 @@ static void     put_fields           (GwyDataField *dfield1,
                                       gint py2);
 
 static const GwyEnum directions[] = {
-    { N_("Up"),            GWY_MERGE_DIRECTION_UP },
-    { N_("Down"),          GWY_MERGE_DIRECTION_DOWN },
-    { N_("Right"),         GWY_MERGE_DIRECTION_RIGHT },
-    { N_("Left"),          GWY_MERGE_DIRECTION_LEFT },
+    { N_("Up"),           GWY_MERGE_DIRECTION_UP,    },
+    { N_("Down"),         GWY_MERGE_DIRECTION_DOWN,  },
+    { N_("adverb|Right"), GWY_MERGE_DIRECTION_RIGHT, },
+    { N_("adverb|Left"),  GWY_MERGE_DIRECTION_LEFT,  },
 };
 
 static const GwyEnum modes[] = {
-    { N_("Correlation"),   GWY_MERGE_MODE_CORRELATE },
-    { N_("None"),          GWY_MERGE_MODE_NONE },
+    { N_("Correlation"),     GWY_MERGE_MODE_CORRELATE, },
+    { N_("merge-mode|None"), GWY_MERGE_MODE_NONE,      },
 };
 
 static const GwyEnum boundaries[] = {
@@ -154,7 +154,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Merges two images."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "1.2",
+    "1.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -373,7 +373,8 @@ merge_do(MergeArgs *args)
             real_boundary = GWY_MERGE_BOUNDARY_SECOND;
         if (args->boundary == GWY_MERGE_BOUNDARY_SECOND)
             real_boundary = GWY_MERGE_BOUNDARY_FIRST;
-    } else {
+    }
+    else {
         real_dir = args->direction;
         real_boundary = args->boundary;
     }
@@ -589,14 +590,13 @@ put_fields(GwyDataField *dfield1, GwyDataField *dfield2,
     xres2 = gwy_data_field_get_xres(dfield2);
     yres2 = gwy_data_field_get_yres(dfield2);
 
+    /* Use the pixels sizes of field 1 but they must be identical. */
     gwy_data_field_set_xreal(result,
-                             gwy_data_field_get_xreal(result)
-                             *gwy_data_field_get_xres(result)
-                             /xres2);
+                             gwy_data_field_get_xres(result)
+                             * gwy_data_field_get_xmeasure(dfield1));
     gwy_data_field_set_yreal(result,
-                             gwy_data_field_get_yreal(result)
-                             *gwy_data_field_get_yres(result)
-                             /yres2);
+                             gwy_data_field_get_yres(result)
+                             * gwy_data_field_get_ymeasure(dfield1));
 
     gwy_data_field_fill(result,
                         MIN(gwy_data_field_get_min(dfield1),
@@ -626,7 +626,7 @@ put_fields(GwyDataField *dfield1, GwyDataField *dfield2,
         gwy_data_field_area_copy(dfield1, result,
                                  x1, y1_, w1, h1,
                                  px1, py1);
-     }
+    }
 
 
     /* adjust boundary to be as smooth as possible */
@@ -643,7 +643,8 @@ put_fields(GwyDataField *dfield1, GwyDataField *dfield2,
             res_rect.y = py2;
             res_rect.height = MAX(MIN(yres1, yres2),
                                   py1 + yres1 - py2 - (yres1 - yres2));
-        } else {
+        }
+        else {
             res_rect.y = py1;
             res_rect.height = py2 + yres2 - py1;
         }
@@ -656,14 +657,10 @@ put_fields(GwyDataField *dfield1, GwyDataField *dfield2,
 
         /*gwy_data_field_area_multiply(result, res_rect.x, res_rect.y,
                                      res_rect.width, res_rect.height, 1.5);*/
-        merge_boundary(dfield1, dfield2, result,
-                       res_rect, f1_pos, f2_pos);
-
+        merge_boundary(dfield1, dfield2, result, res_rect, f1_pos, f2_pos);
     }
-
 }
 
-
 /* compute corelation */
 static gboolean
 get_score_iteratively(GwyDataField *data_field, GwyDataField *kernel_field,
@@ -758,6 +755,7 @@ merge_boundary(GwyDataField *dfield1,
 
             weight = 0.5; /*FIXME adapt weight to direction*/
 
+            /* FIXME: This sometimes asks for values outside the field. */
             val1 = gwy_data_field_get_val(dfield1,
                                           col + f1_pos.x, row + f1_pos.y);
             val2 = gwy_data_field_get_val(dfield2,
@@ -778,12 +776,12 @@ merge_sanitize_args(MergeArgs *args)
 {
     args->direction = MIN(args->direction, GWY_MERGE_DIRECTION_LAST - 1);
     args->mode = MIN(args->mode, GWY_MERGE_MODE_LAST - 1);
-    args->boundary = MIN(args->boundary, GWY_MERGE_BOUNDARY_LAST - 2);
+    args->boundary = MIN(args->boundary, GWY_MERGE_BOUNDARY_LAST - 1);
 }
 
 static void
 merge_load_args(GwyContainer *settings,
-                   MergeArgs *args)
+                MergeArgs *args)
 {
     *args = merge_defaults;
     gwy_container_gis_enum_by_name(settings, direction_key, &args->direction);
@@ -794,7 +792,7 @@ merge_load_args(GwyContainer *settings,
 
 static void
 merge_save_args(GwyContainer *settings,
-                   MergeArgs *args)
+                MergeArgs *args)
 {
     gwy_container_set_enum_by_name(settings, direction_key, args->direction);
     gwy_container_set_enum_by_name(settings, mode_key, args->mode);
