@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: polydistort.c 10348 2009-11-02 22:56:33Z yeti-dn $
+ *  @(#) $Id: polydistort.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2007,2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -274,9 +274,12 @@ distort_dialog(DistortArgs *args,
         = gwy_enum_combo_box_newl(G_CALLBACK(exterior_changed), &controls,
                                   args->exterior,
                                   _("Minimum"), GWY_EXTERIOR_FIXED_VALUE,
-                                  _("Border"), GWY_EXTERIOR_BORDER_EXTEND,
-                                  _("Mirror"), GWY_EXTERIOR_MIRROR_EXTEND,
-                                  _("Periodic"), GWY_EXTERIOR_PERIODIC,
+                                  gwy_sgettext("exterior|Border"),
+                                  GWY_EXTERIOR_BORDER_EXTEND,
+                                  gwy_sgettext("exterior|Mirror"),
+                                  GWY_EXTERIOR_MIRROR_EXTEND,
+                                  gwy_sgettext("exterior|Periodic"),
+                                  GWY_EXTERIOR_PERIODIC,
                                   NULL);
     gwy_table_attach_hscale(table, row, _("_Exterior type:"), NULL,
                             GTK_OBJECT(controls.exterior),
