@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: scale.c 11394 2010-09-15 12:01:39Z yeti-dn $
+ *  @(#) $Id: scale.c 12379 2011-05-09 22:11:33Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -189,7 +189,7 @@ scale_dialog(ScaleArgs *args)
     enum { RESPONSE_RESET = 1 };
     gint response;
 
-    dialog = gtk_dialog_new_with_buttons(_("Scale"), NULL, 0,
+    dialog = gtk_dialog_new_with_buttons(gwy_sgettext("verb|Scale"), NULL, 0,
                                          _("_Reset"), RESPONSE_RESET,
                                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                          GTK_STOCK_OK, GTK_RESPONSE_OK,
