@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: synth.h 11523 2010-11-11 15:04:36Z yeti-dn $
+ *  @(#) $Id: synth.h 12126 2011-02-26 10:45:26Z yeti-dn $
  *  Copyright (C) 2009,2010 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -73,6 +73,10 @@ static gint          gwy_synth_attach_height         (GWY_SYNTH_CONTROLS *contro
                                                       const gchar *name,
                                                       GtkWidget **pspin,
                                                       GtkWidget **punits);
+static gint          gwy_synth_attach_roundness      (GWY_SYNTH_CONTROLS *controls,
+                                                      gint row,
+                                                      GtkObject **adj,
+                                                      gdouble *target);
 static gint          gwy_synth_attach_orientation    (GWY_SYNTH_CONTROLS *controls,
                                                       gint row,
                                                       GtkObject **adj,
@@ -314,6 +318,7 @@ gwy_synth_attach_height(GWY_SYNTH_CONTROLS *controls,
 
     spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
                                    row, name, "", *adj, GWY_HSCALE_LOG);
+    gtk_spin_button_set_digits(GTK_SPIN_BUTTON(spin), 4);
     if (pspin)
         *pspin = spin;
 
@@ -325,6 +330,34 @@ gwy_synth_attach_height(GWY_SYNTH_CONTROLS *controls,
     return row;
 }
 
+G_GNUC_UNUSED
+static gint
+gwy_synth_attach_roundness(GWY_SYNTH_CONTROLS *controls,
+                           gint row,
+                           GtkObject **adj,
+                           gdouble *target)
+{
+    GtkWidget *spin;
+
+    gtk_table_set_row_spacing(controls->table, row-1, 8);
+    gtk_table_attach(controls->table, gwy_label_new_header(_("Roundness")),
+                     0, 3, row, row+1, GTK_FILL, 0, 0, 0);
+    row++;
+
+    *adj = gtk_adjustment_new(*target, 0.0, 1.0, 0.001, 0.1, 0);
+    g_object_set_data(G_OBJECT(*adj), "target", target);
+
+    spin = gwy_table_attach_hscale(GTK_WIDGET(controls->table),
+                                   row, _("Roundn_ess:"), NULL, *adj,
+                                   GWY_HSCALE_DEFAULT);
+    g_signal_connect_swapped(*adj, "value-changed",
+                             G_CALLBACK(gwy_synth_double_changed), controls);
+
+    row++;
+
+    return row;
+}
+
 G_GNUC_UNUSED
 static gint
 gwy_synth_attach_orientation(GWY_SYNTH_CONTROLS *controls,
@@ -484,7 +517,7 @@ gwy_synth_random_seed_new(GWY_SYNTH_CONTROLS *controls,
     *adj = gtk_adjustment_new(*target, 1, 0x7fffffff, 1, 10, 0);
     g_object_set_data(G_OBJECT(*adj), "target", target);
     g_signal_connect_swapped(*adj, "value-changed",
-                             G_CALLBACK(gwy_synth_double_changed), controls);
+                             G_CALLBACK(gwy_synth_int_changed), controls);
 
     label = gtk_label_new_with_mnemonic(_("R_andom seed:"));
     gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
